@@ -40,13 +40,18 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         self.keep_alive = True
         self.use_cookie = True
         self.debug = False
-        self.verify_ssl = False
+        self.validate_cert = True
+        self._headers = {}
 
 
     def set_user_agent(self, user_agent):
         self._user_agent = user_agent
 
 
+    def set_global_headers(self, headers):
+        self._headers = headers
+
+
     def set_proxy(self, host, port = 8080, username = None, password = None):
         assert isinstance(port, (int, long))
         self._proxy["proxy_host"] = host
@@ -66,10 +71,8 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         def _wrap_prepare_curl_callback(curl):
             if self.use_cookie:
                 curl.setopt(pycurl.COOKIEFILE, "")
-                #curl.setopt(pycurl.COOKIEJAR, "")
+                curl.setopt(pycurl.COOKIEJAR, "")
 
-            if not self.verify_ssl:
-                curl.setopt(pycurl.SSL_VERIFYPEER, 0)
 
             if self.debug:
                 curl.setopt(pycurl.VERBOSE, 1)
@@ -105,7 +108,9 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
 
 
         headers = kwargs.pop("headers", {})
+        headers.update(self._headers)
         self.keep_alive and headers.update(Connection = "keep-alive")
+        kwargs.update(validate_cert = self.validate_cert)
 
         super(TornadoHTTPClient, self).fetch(request, callback, headers = headers, **kwargs)
 
